@@ -119,12 +119,10 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
         value_int = StrToNumber(value_str)
 
         try:
-            attribute = Document_attributes.objects.row(f'''select *
-                                                            from kd_document_attributes
-                                                            where delete_dbl_spaces(value_str) = %s
-                                                              and attr_type_id = %s
-                                                              and value_int = %s  
-                                                            order by id''', [delete_dbl_spaces(value_str), attr_type.id, value_int])[0]
+            attribute = Document_attributes.objects.filter(
+                value_str__delete_dbl_spaces=delete_dbl_spaces(value_str),
+                attr_type=attr_type,
+            ).order_by('id')[0]
             settings.LOCKS.release('Document_attributesManager.get_or_create_attribute')
             return attribute, False
         except IndexError:
