@@ -107,7 +107,7 @@ class Lotsman_documents_hierarcyManagerExt:
             mat_view_name = create_tmp_mat_view(sql_str=sql_str, indexes=['attr_name', 'parent_id'])
 
             with connection.cursor() as cursor:
-                cursor.execute(f'select count(*) from {mat_view_name}')
+                cursor.execute(f'select count(*) from {mat_view_name} where props=1')
                 cnt, = cursor.fetchone()
 
             # logger.logging(f'''SPC_CLM_NAME: {lotsman_documents_hierarcy_view_record.SPC_CLM_NAME.value_str}''', 'debug')
@@ -126,7 +126,7 @@ class Lotsman_documents_hierarcyManagerExt:
                         with transaction.atomic():
 
                             Tmp_Item_refsManager.create()
-                            for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} order by level'''):
+                            for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name}  where props=1 order by level'''):
                                 if lotsman_documents_hierarcy.attr_name not in ['Материал']:
 
                                     item, created1 = self.get_item(
@@ -134,7 +134,7 @@ class Lotsman_documents_hierarcyManagerExt:
                                         items_pairs=items_pairs,
                                     )
 
-                                    if lotsman_documents_hierarcy.parent_id:
+                                    if lotsman_documents_hierarcy.parent_id != None:
                                         try:
                                             _lotsman_documents_hierarcy = Lotsman_documents_hierarcy_view.objects.get(id=lotsman_documents_hierarcy.parent_id)
                                         except Lotsman_documents_hierarcy_view.DoesNotExist as ex:
@@ -154,18 +154,20 @@ class Lotsman_documents_hierarcyManagerExt:
                                     #     pass
                                     # END FOR DEBUG
 
-                                Lotsman_documents_hierarcy.objects.update_or_create(
-                                    id=lotsman_documents_hierarcy.id,
-                                    defaults=dict(
-                                        props=lotsman_documents_hierarcy.props | Lotsman_documents_hierarcy.props.beenItemed
-                                    ))
+                                else:
+                                    Lotsman_documents_hierarcy.objects.update_or_create(
+                                        id=lotsman_documents_hierarcy.id,
+                                        defaults=dict(
+                                            props=lotsman_documents_hierarcy.props | Lotsman_documents_hierarcy.props.beenItemed
+                                        ))
 
                                 res = progress.step()
                                 if res != 0:
                                     raise ProgressDroped(progress_deleted)
 
+                            progress.close()
                             with connection.cursor() as cursor:
-                                cursor.execute(f'''select count(*) from {mat_view_name} where attr_name=%s''', ['''Сборочная единица'''])
+                                cursor.execute(f'''select count(*) from {mat_view_name} where props=1 and attr_name=%s''', ['''Сборочная единица'''])
                                 assmbl_progress_count, = cursor.fetchone()
 
                             with managed_progress(
@@ -174,15 +176,16 @@ class Lotsman_documents_hierarcyManagerExt:
                                     user=self.user,
                                     message=f'''Создание сборочных единиц. ({assmbl_progress_count}  шт.)''',
                                     title='Выполнено',
-                                    # props=TurnBitOn(0, 0)
+                                    props=TurnBitOn(0, 0)
                             ) as assmbl_progress:
 
                                 # logger.logging(f'''Сборочные единицы SPC_CLM_NAME: {lotsman_documents_hierarcy_view_record.SPC_CLM_NAME.value_str}''', 'debug')
                                 # logger.logging(f'qty: {assmbl_progress_count}', 'debug')
 
-                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where attr_name=%s order by level''', ['''Сборочная единица''']):
+                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where props=1 and attr_name=%s order by level''', ['''Сборочная единица''']):
+
                                     assmbl_progress.setContentsLabel(f'''<h3>Создание сборочной единицы. ({lotsman_documents_hierarcy.SPC_CLM_NAME.value_str if lotsman_documents_hierarcy.SPC_CLM_NAME else ''} : 
-                                                                                                             {lotsman_documents_hierarcy.SPC_CLM_MARK.value_str if lotsman_documents_hierarcy.SPC_CLM_MARK else ''})</h3>''')
+                                                                                                          {lotsman_documents_hierarcy.SPC_CLM_MARK.value_str if lotsman_documents_hierarcy.SPC_CLM_MARK else ''})</h3>''')
                                     item, _ = self.get_item(
                                         lotsman_documents_hierarcy=lotsman_documents_hierarcy,
                                         items_pairs=items_pairs,
@@ -196,13 +199,18 @@ class Lotsman_documents_hierarcyManagerExt:
                                         record=lotsman_documents_hierarcy_view_record,
                                     )
 
-                                    assmbl_progress.step()
-                                    res = progress.step()
+                                    Lotsman_documents_hierarcy.objects.update_or_create(
+                                        id=lotsman_documents_hierarcy.id,
+                                        defaults=dict(
+                                            props=lotsman_documents_hierarcy.props | Lotsman_documents_hierarcy.props.beenItemed
+                                        ))
+
+                                    res = assmbl_progress.step()
                                     if res != 0:
                                         raise ProgressDroped(progress_deleted)
 
                             with connection.cursor() as cursor:
-                                cursor.execute(f'''select count(*) from {mat_view_name} where attr_name=%s''', ['''Чертеж'''])
+                                cursor.execute(f'''select count(*) from {mat_view_name} where props=1 and attr_name=%s''', ['''Чертеж'''])
                                 assmbl_progress_count, = cursor.fetchone()
 
                             with managed_progress(
@@ -211,13 +219,13 @@ class Lotsman_documents_hierarcyManagerExt:
                                     user=self.user,
                                     message=f'''Привязка чертежей. ({assmbl_progress_count}  шт.)''',
                                     title='Выполнено',
-                                    # props=TurnBitOn(0, 0)
+                                    props=TurnBitOn(0, 0)
                             ) as assmbl_progress:
 
                                 # logger.logging(f'''Чертежи SPC_CLM_NAME: {lotsman_documents_hierarcy_view_record.SPC_CLM_NAME.value_str}''', 'debug')
                                 # logger.logging(f'qty: {assmbl_progress_count}', 'debug')
 
-                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where attr_name=%s order by level''', ['''Чертеж''']):
+                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where props=1 and attr_name=%s order by level''', ['''Чертеж''']):
 
                                     assmbl_progress.setContentsLabel(f'''<h3>Привязка чертежей. ({lotsman_documents_hierarcy.SPC_CLM_NAME.value_str if lotsman_documents_hierarcy.SPC_CLM_NAME else ''} : 
                                                                                                     {lotsman_documents_hierarcy.SPC_CLM_MARK.value_str if lotsman_documents_hierarcy.SPC_CLM_MARK else ''})</h3>''')
@@ -234,9 +242,13 @@ class Lotsman_documents_hierarcyManagerExt:
                                             )
                                             item_ref.delete()
 
-                                    assmbl_progress.step()
+                                    Lotsman_documents_hierarcy.objects.update_or_create(
+                                        id=lotsman_documents_hierarcy.id,
+                                        defaults=dict(
+                                            props=lotsman_documents_hierarcy.props | Lotsman_documents_hierarcy.props.beenItemed
+                                        ))
 
-                                    res = progress.step()
+                                    res = assmbl_progress.step()
                                     if res != 0:
                                         raise ProgressDroped(progress_deleted)
 
@@ -246,10 +258,10 @@ class Lotsman_documents_hierarcyManagerExt:
                                     user=self.user,
                                     message=f'''Перемещение чертежей. ({assmbl_progress_count}  шт.)''',
                                     title='Выполнено',
-                                    # props=TurnBitOn(0, 0)
+                                    props=TurnBitOn(0, 0)
                             ) as assmbl_progress:
 
-                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where attr_name=%s order by level''', ['''Чертеж''']):
+                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where props=1 and attr_name=%s order by level''', ['''Чертеж''']):
                                     item, _ = self.get_item(
                                         lotsman_documents_hierarcy=lotsman_documents_hierarcy,
                                         items_pairs=items_pairs,
@@ -258,9 +270,7 @@ class Lotsman_documents_hierarcyManagerExt:
                                     if Item_refs.objects.filter(child=item).count() == 0 and Item_refs.objects.filter(parent=item).count() == 0:
                                         item.delete()
 
-                                    assmbl_progress.step()
-
-                                    res = progress.step()
+                                    res = assmbl_progress.step()
                                     if res != 0:
                                         raise ProgressDroped(progress_deleted)
 
@@ -268,6 +278,12 @@ class Lotsman_documents_hierarcyManagerExt:
                         Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
                         raise ex
 
+            # FOR DEBUG
+            with connection.cursor() as cursor:
+                cursor.execute(f'''select count(*) from kd_lotsman_documents_hierarcy where props=1''')
+                count, = cursor.fetchone()
+            # END FOR DEBUG
+
             drop_mat_view(mat_view_name)
         except Exception as ex:
             drop_mat_view(mat_view_name)
@@ -293,7 +309,7 @@ class Lotsman_documents_hierarcyManagerExt:
                 id=f'''lines_{parent.id}''',
                 qty=count,
                 user=user_id,
-                message=f'''Создание строк детализации. ({count} шт.)''',
+                message=f'''Создание строк детализации. ({parent.item_name}) ({count} строк.)''',
                 title='Выполнено'
         ) as lines_progress:
             for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'select * from {mat_view_name} where parent_id=%s order by level', [parent.lotsman_document.id]):
