@@ -35,7 +35,20 @@ def Uploades_Add(request):
     _request = DSRequest(request=request)
     data = _request.get_data()
 
-    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Uploades/Add', params=dict(path_id=data.get('path_id'), port=ws_port, ws_channel=ws_channel, host=host))
+    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Uploades/Add', params=dict(path_id=data.get('path_id'), port=ws_port, ws_channel=ws_channel, host=host, mode='Add'))
+    HttpResponseRedirect(r.url)
+    return JsonResponse(DSResponse(request=request, status=RPCResponseConstant.statusSuccess).response)
+
+@JsonResponseWithException()
+def Uploades_Calc(request):
+    ws_channel = request.session.get('ws_channel')
+    ws_port = settings.WS_PORT
+    host = settings.WS_HOST
+
+    _request = DSRequest(request=request)
+    data = _request.get_data()
+
+    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Uploades/Calc', params=dict(path_id=data.get('path_id'), port=ws_port, ws_channel=ws_channel, host=host, mode='Calc'))
     HttpResponseRedirect(r.url)
     return JsonResponse(DSResponse(request=request, status=RPCResponseConstant.statusSuccess).response)
 
